@@ -6,6 +6,47 @@ def referenceMaterial():
     #Open reference material
     pass
 
+def vd(v2,v1):
+    """
+    Differential voltage
+    v1 = voltage between inverting terminal and ground
+    v2 = voltage between non-inverting terminal and ground
+    """
+    return v2-v1
+
+def i_out(i1,i2,i_plus, i_minus):
+    """Output current"""
+    return sum(i1, i2, i_plus, i_minus)
+
+def v_o(A,vd):
+    """
+    Open loop voltage gain.
+    Gain of the op amp without any external feedback from output to input.
+    Sometimes voltage gain (A) is expressed in decibels (dB).
+    A dB = 20*log_10(A)
+
+    Usage:
+        v_out(4, vd(4,6))
+    """
+    return A*vd
+
+def mode(v_o, Vcc):
+    """
+    A practical limitation of the op amp is that the magnitude of its output voltage cannot exceed abs(Vcc).
+    The output voltage is dependent on an limited by the power supply voltage.
+
+    Although we shall always operate the op amp in the linear region, the
+    possibility of saturation must be borne in mind when one designs with
+    op amps, to avoid designing op amp circuits that will not work in the
+    laboratory.
+    """
+    if v_o == Vcc:
+        return "positive saturation"
+    if v_o >= -Vcc and v_o <= Vcc:
+        return "linear region"
+    if v_o == -Vcc:
+        return "negative saturation"
+
 def invertingAmplifier(find="v_out", printEq=False, **kwargs):
     """variables
                 v_out, v_in = voltage out/in
